/*
    Copyright  1995-2001, The AROS Development Team. All rights reserved.
    $Id: closelocale.c,v 1.3 2010/03/03 16:00:38 tokai Exp $

    Desc: CloseLocale() - Close a locale structure.
    Lang: english
*/
#include <exec/types.h>
#include <proto/exec.h>
#include "locale_intern.h"

/*****************************************************************************

    NAME */
#include <proto/locale.h>

	AROS_LH1(void, CloseLocale,

/*  SYNOPSIS */
	AROS_LHA(struct Locale *, locale, A0),

/*  LOCATION */
	struct LocaleBase *, LocaleBase, 7, Locale)

/* ---- locale.library/CloseLocale
 *
 *   NAME
 *        CloseLocale -- Close a locale structure.
 * 
 *   FUNCTION
 *        Finish accessing a Locale.
 *
 *   INPUTS
 *        locale - An opened locale. Note that NULL is a valid
 *                 parameter here, and will simply be ignored.
 *
 *   RESULT
 *        The locale is released back to the system.
 *
 *   SEE ALSO
 *        OpenLocale()
 *
 * ----
 *
 *   INTERNALS
 *
 *   HISTORY
 *   27-11-96    digulla automatically created from
 *               locale_lib.fd and clib/locale_protos.h
 */
{
	AROS_LIBFUNC_INIT
	AROS_LIBBASE_EXT_DECL(struct Library *,LocaleBase)

	/* Best make sure we actually have something freeable. */
	if(locale && (locale != (struct Locale *)IntLB(LocaleBase)->lb_DefaultLocale))
	{
		InternalCloseLocale(locale);
	}

	AROS_LIBFUNC_EXIT
} /* CloseLocale */


VOID _InternalCloseLocale(struct Locale *locale, APTR LocaleBase)
{
	/* Make sure we don't have any race conditions */
	ObtainSemaphore(&IntLB(LocaleBase)->lb_LocaleLock);
	if(--IntL(locale)->il_Count == 0)
	{
	    /* Free the locale structure if it's not the current locale */
	    if (locale != (struct Locale *)IntLB(LocaleBase)->lb_CurrentLocale)
	    {
	      /* Close old .language, if any */

	      if (IntL(locale)->il_CurrentLanguage)
	        CloseLibrary(IntL(locale)->il_CurrentLanguage);

	      /* Close old dos.catalog */
	      CloseCatalog(IntL(locale)->il_DosCatalog);

	      FreeMem(locale, sizeof(struct IntLocale));
	    }
	}
	ReleaseSemaphore(&IntLB(LocaleBase)->lb_LocaleLock);
}
